
# Slot: value


example value

URI: [linkml:value](https://w3id.org/linkml/value)


## Domain and Range

[Example](Example.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [Example](Example.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | skos:example |

